from .cli import pareidolia_cmd

if __name__ == "__main__":
    pareidolia_cmd()  # pylint: disable=no-value-for-parameter
